==> ackee-frontend-toolkit-0.8.2.tgz: package/es/modules/chat/components/Conversations/SearchForm.js <==
import { React, PropTypes, Form, Field, reduxForm, injectIntl, compose } from '../../dependencies';

import constants from '../../constants';

var SearchForm = function SearchForm(_ref) {
    var handleSubmit = _ref.handleSubmit,
        intl = _ref.intl,
        pristine = _ref.pristine,
        submitting = _ref.submitting,
        searchLabel = _ref.searchLabel;
    return React.createElement(
        'div',
        { className: 'conversations__search-form' },
        React.createElement(
            Form,
            { className: 'form', onSubmit: handleSubmit },
            React.createElement(Field, {
                name: 'text',
                type: 'text',
                component: 'input',
                placeholder: intl.formatMessage({ id: 'chat.conversations.search.placeholder' })
            }),
            searchLabel && React.createElement(
                'button',
                {
                    disabled: pristine || submitting,
                    type: 'submit'
                },
                searchLabel
            )
        )
    );
};

SearchForm.propTypes = {
    handleSubmit: PropTypes.func.isRequired,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func
    }).isRequired,
    pristine: PropTypes.bool.isRequired,
    submitting: PropTypes.bool.isRequired,
    searchLabel: PropTypes.node
};

SearchForm.defaultProps = {
    searchLabel: null
};

export default compose(injectIntl, reduxForm({
    form: constants.SEARCH_CONVERSATION_FORM_ID
}))(SearchForm);

==> ackee-frontend-toolkit-0.13.0.tgz: package/es/modules/chat/components/Conversations/SearchForm.js <==
import { React, PropTypes, Form, Field, reduxForm, injectIntl, compose } from '../../dependencies';

import constants from '../../services/constants';

var SearchForm = function SearchForm(_ref) {
    var handleSubmit = _ref.handleSubmit,
        intl = _ref.intl,
        pristine = _ref.pristine,
        submitting = _ref.submitting,
        searchLabel = _ref.searchLabel;
    return React.createElement(
        'div',
        { className: 'conversations__search-form' },
        React.createElement(
            Form,
            { className: 'form', onSubmit: handleSubmit },
            React.createElement(Field, {
                name: 'text',
                type: 'text',
                component: 'input',
                placeholder: intl.formatMessage({
                    id: 'chat.conversations.search.placeholder'
                })
            }),
            searchLabel && React.createElement(
                'button',
                { disabled: pristine || submitting, type: 'submit' },
                searchLabel
            )
        )
    );
};

SearchForm.propTypes = {
    handleSubmit: PropTypes.func.isRequired,
    intl: PropTypes.shape({
        formatMessage: PropTypes.func
    }).isRequired,
    pristine: PropTypes.bool.isRequired,
    submitting: PropTypes.bool.isRequired,
    searchLabel: PropTypes.node
};

SearchForm.defaultProps = {
    searchLabel: null
};

export default compose(injectIntl, reduxForm({
    form: constants.SEARCH_CONVERSATION_FORM_ID
}))(SearchForm);
